==> rest-sdk-web-api-0.3.0-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/webapi/parser/amf/AMFTypeSchemaSupplier.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.webapi.parser.amf;

import static javax.ws.rs.core.MediaType.APPLICATION_XML_TYPE;

import java.io.StringWriter;
import java.util.function.Supplier;

import javax.ws.rs.core.MediaType;

import amf.client.model.domain.AnyShape;
import amf.client.render.ShapeRenderOptions;
import amf.plugins.xml.transformer.TypeToXmlSchema;
import org.apache.ws.commons.schema.XmlSchema;

public class AMFTypeSchemaSupplier implements Supplier<String> {

  private static final ShapeRenderOptions RENDER_OPTIONS =
      new ShapeRenderOptions().withoutDocumentation().withCompactedEmission();

  private final AnyShape shape;
  private final MediaType mediaType;

  AMFTypeSchemaSupplier(AnyShape shape, MediaType mediaType) {
    this.shape = shape;
    this.mediaType = mediaType;
  }

  @Override
  public String get() {
    if (mediaType != null && mediaType.equals(APPLICATION_XML_TYPE)) {
      return buildXmlTypeSchema(shape);
    } else {
      return shape.buildJsonSchema(RENDER_OPTIONS);
    }
  }

  private String buildXmlTypeSchema(AnyShape anyShape) {
    XmlSchema xmlSchema = TypeToXmlSchema.transform("root", anyShape._internal());
    xmlSchema.setTargetNamespace("http://validationnamespace.raml.org");

    StringWriter schemaWriter = new StringWriter();
    xmlSchema.write(schemaWriter);
    return schemaWriter.toString();
  }
}

==> rest-sdk-web-api-0.6.0-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/webapi/parser/amf/AMFTypeSchemaSupplier.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.webapi.parser.amf;

import static javax.ws.rs.core.MediaType.APPLICATION_XML_TYPE;

import java.io.StringWriter;
import java.util.function.Supplier;

import javax.ws.rs.core.MediaType;

import amf.client.model.domain.AnyShape;
import amf.client.render.ShapeRenderOptions;
import amf.plugins.xml.transformer.TypeToXmlSchema;
import org.apache.ws.commons.schema.XmlSchema;

public class AMFTypeSchemaSupplier implements Supplier<String> {

  private static final ShapeRenderOptions RENDER_OPTIONS =
      new ShapeRenderOptions().withCompactedEmission();

  private final AnyShape shape;
  private final MediaType mediaType;

  AMFTypeSchemaSupplier(AnyShape shape, MediaType mediaType) {
    this.shape = shape;
    this.mediaType = mediaType;
  }

  @Override
  public String get() {
    if (mediaType != null && mediaType.equals(APPLICATION_XML_TYPE)) {
      return buildXmlTypeSchema(shape);
    } else {
      return shape.buildJsonSchema(RENDER_OPTIONS);
    }
  }

  private String buildXmlTypeSchema(AnyShape anyShape) {
    XmlSchema xmlSchema = TypeToXmlSchema.transform("root", anyShape._internal());
    xmlSchema.setTargetNamespace("http://validationnamespace.raml.org");

    StringWriter schemaWriter = new StringWriter();
    xmlSchema.write(schemaWriter);
    return schemaWriter.toString();
  }
}
